@@ -97,7 +97,7 @@ simFromDAG <- function(DAG, Nsamp, wide = TRUE, LTCF = NULL, rndseed = NULL, rnd
       # print("distparam: "); print(distparam)
       # print("class(distparam): "); print(class(distparam))
 
-      if (class(distparam)%in%"list") {
+      if (is(distparam,"list")) {
         distparam <- lapply(distparam, check_len)
         distparam <- do.call("cbind", distparam)
       } else if (is.vector(distparam)) {
@@ -883,4 +883,4 @@ DF.to.longDT <- function(df_wide, return_DF = TRUE) {
 # 	v.names <- NULL
 # 	simdf_wide <- reshape(data=simdf_long, idvar=, varying=varying, v.names=v.names, timevar = "t", times = all_ts, sep="_", direction="wide")
 # 	simdf_wide
-# }
\ No newline at end of file
+# }
